# `BioClients.chebi`

## ChEBI

Tools for obtaining and processing ChEBI data.
Chemical Entities of Biological Interest (ChEBI) is a freely available dictionary
of molecular entities focused on ‘small’ chemical compounds.

* <https://www.ebi.ac.uk/chebi/>
* <https://www.ebi.ac.uk/chebi/webServices.do>

